﻿using System;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;

namespace GGJ_Game
{
    /// <summary>
    /// This class update animations from a spritesheet and draws the current one
    /// </summary>
    class AnimationPlayer
    {
        public int currentFrame;
        public float timeInFrame;
        SpriteSheet spriteSheet;

        public AnimationPlayer()
        {
            currentFrame = 0;
            timeInFrame = 0;
            spriteSheet = null;
        }

        public void PlayAnimation(SpriteSheet spriteSheet, AnimationPlayer syncToThis = null)
        {
            // skip if new anim is old anim
            if (this.spriteSheet == spriteSheet)
                return;

            this.spriteSheet = spriteSheet;

            if (syncToThis != null)
            {
                currentFrame = syncToThis.currentFrame;
                timeInFrame = syncToThis.timeInFrame;
            }
            else
            {
                currentFrame = 0;
                timeInFrame = 0;
            }
        }

        public void Update(GameTime gameTime)
        {
            // Update animation
            timeInFrame += (float)gameTime.ElapsedGameTime.TotalSeconds;

            if (spriteSheet == null)
                return;

            while (timeInFrame > spriteSheet.FrameTime)
            {
                // Show next frame
                timeInFrame -= spriteSheet.FrameTime;
                ++currentFrame;

                if (currentFrame > spriteSheet.FrameCount()-1)
                {
                    currentFrame = 0;
                }
            }
        }

        public void Draw(GameTime gameTime, SpriteBatch spriteBatch, Vector2 position, SpriteEffects effects)
        {
            if (spriteSheet == null)
                return;

            // Calculate the source rectangle of the current frame.
            Rectangle source = new Rectangle(currentFrame * spriteSheet.Texture.Height, 0, spriteSheet.Texture.Height, spriteSheet.Texture.Height);

            spriteBatch.Draw(spriteSheet.Texture, position, source, Color.White, 0.0f, Orgin, 1.0f, effects, 0);
        }

        // Returns the center button offset
        public Vector2 Orgin
        {
            get
            {
                return new Vector2(spriteSheet.FrameWidth() / 2.0f, spriteSheet.FrameHeight());
            }
        }
    }
}
